Module common

Module common 

Mechanical helpers shared by pairwise transforms.

This module must not become a unified provider IR. Keep provider-specific field decisions in the pair module that owns the conversion.

Re-exports

pub use claude_mid_conv_system::*;
pub use errors::*;
pub use metadata::*;
pub use roles::*;
pub use sse::*;
pub use tools::*;
pub use usage::*;

Modules

claude_mid_conv_system
Claude model capability gate for mid-conversation system turns (mid_conv_system content block / system message role).
errors
metadata
roles
sse
tools
usage
utf8
Incremental UTF-8 decoding for byte streams.