pub fn synthesize_sse(
kind: ContentGenerationKind,
body: &[u8],
) -> Result<Vec<u8>, TransformError>Expand description
Turn one complete response into the smallest useful SSE event sequence.
pub fn synthesize_sse(
kind: ContentGenerationKind,
body: &[u8],
) -> Result<Vec<u8>, TransformError>Turn one complete response into the smallest useful SSE event sequence.